@@ -1,7 +1,7 @@
 #
 #   anova.ppm.R
 #
-#  $Revision: 1.24 $   $Date: 2016/04/25 02:34:40 $
+#  $Revision: 1.25 $   $Date: 2016/10/23 10:36:58 $
 #
 
 anova.ppm <- local({
@@ -52,14 +52,14 @@ anova.ppm <- local({
       if((nT <- length(Terms)) > 0) {
         ## generate models by adding terms sequentially
         objex <- vector(mode="list", length=nT+1)
-        for(n in 1:nT) {
+        for(n in 1L:nT) {
           ## model containing terms 1, ..., n-1
           fmla <- paste(". ~ . - ", paste(Terms[n:nT], collapse=" - "))
           fmla <- as.formula(fmla)
           objex[[n]] <- update(object, fmla)
         }
         ## full model
-        objex[[nT+1]] <- object
+        objex[[nT+1L]] <- object
         expandedfrom1 <- TRUE
       }
     }
@@ -83,11 +83,11 @@ anova.ppm <- local({
     if(length(objex) > 1) {
       ## same data? 
       datas <- lapply(objex, data.ppm)
-      samedata <- all(sapply(datas[-1], identical, y=datas[[1]]))
+      samedata <- all(sapply(datas[-1L], identical, y=datas[[1L]]))
       if(!samedata) stop("Models were fitted to different datasets")
       ## same dummy points?
       quads <- lapply(objex, quad.ppm)
-      samequad <- all(sapply(quads[-1], identical, y=quads[[1]]))
+      samequad <- all(sapply(quads[-1L], identical, y=quads[[1L]]))
       if(!samequad) {
         gripe("Models were re-fitted using a common quadrature scheme")
         sizes <- sapply(quads, nquad)
@@ -165,7 +165,7 @@ anova.ppm <- local({
     ## replace 'residual df' by number of parameters in model
     if("Resid. Df" %in% names(result)) {
       ## count number of quadrature points used in each model
-      obj1 <- objex[[1]]
+      obj1 <- objex[[1L]]
       ss <- getglmsubset(obj1)
       nq <- if(!is.null(ss)) sum(ss) else n.quad(quad.ppm(obj1))
       result[, "Resid. Df"] <- nq - result[, "Resid. Df"]
@@ -182,15 +182,15 @@ anova.ppm <- local({
       h <- gsub("Model: binomial, link: logit", "", h)
       h <- gsub("Response: ", "", h)
       ## remove blank lines (up to 4 consecutive blanks can occur)
-      for(i in 1:5)
+      for(i in 1L:5L)
         h <- gsub("\n\n", "\n", h)
       if(length(objex) > 1 && length(h) > 1) {
         ## anova(mod1, mod2, ...)
         ## change names of models
         fmlae <- sapply(objex, fmlaString)
         intrx <- sapply(objex, interString)
-        h[2] <- paste("Model",
-                      paste0(1:length(objex), ":"),
+        h[2L] <- paste("Model",
+                      paste0(1L:length(objex), ":"),
                       fmlae,
                       "\t",
                       intrx,
@@ -198,7 +198,7 @@ anova.ppm <- local({
       }
       ## Add explanation if we did the stepwise thing ourselves
       if(expandedfrom1)
-        h <- c(h[1], "Terms added sequentially (first to last)\n", h[-1])
+        h <- c(h[1L], "Terms added sequentially (first to last)\n", h[-1L])
       ## Contract spaces in output if spatstat.options('terse') >= 2
       if(!waxlyrical('space'))
         h <- gsub("\n$", "", h)
@@ -273,8 +273,8 @@ anova.ppm <- local({
         cn <- colnames(result)
         colnames(result)[cn == "Deviance"] <- "AdjDeviance"
         if("Pr(>Chi)" %in% colnames(result)) 
-          result[["Pr(>Chi)"]] <- c(NA, pchisq(abs(AdjDev[-1]),
-                                               df=abs(result$Df[-1]),
+          result[["Pr(>Chi)"]] <- c(NA, pchisq(abs(AdjDev[-1L]),
+                                               df=abs(result$Df[-1L]),
                                                lower.tail=FALSE))
         class(result) <- class(oldresult)
         attr(result, "heading") <- attr(oldresult, "heading")
