@@ -3,13 +3,13 @@
 #
 #   Delta metric
 #
-#   $Revision: 1.3 $  $Date: 2010/07/10 11:42:08 $
+#   $Revision: 1.4 $  $Date: 2014/10/24 00:22:30 $
 #
 
 deltametric <- function(A, B, p=2, c=Inf, ...) {
   stopifnot(is.numeric(p) && length(p) == 1 && p > 0)
   # ensure frames are identical
-  bb <- bounding.box(as.rectangle(A), as.rectangle(B))
+  bb <- boundingbox(as.rectangle(A), as.rectangle(B))
   # enforce identical frames
   A <- rebound(A, bb)
   B <- rebound(B, bb)
@@ -17,8 +17,8 @@ deltametric <- function(A, B, p=2, c=Inf, ...) {
   dA <- distmap(A, ...)
   dB <- distmap(B, ...)
   if(!is.infinite(c)) {
-    dA <- eval.im(pmin(dA, c))
-    dB <- eval.im(pmin(dB, c))
+    dA <- eval.im(pmin.int(dA, c))
+    dB <- eval.im(pmin.int(dB, c))
   }
   if(is.infinite(p)) {
     # L^infinity
