@@ -1,48 +1,54 @@
 #
 # lpp.R
 #
-#  $Revision: 1.46 $   $Date: 2016/07/17 05:08:14 $
+#  $Revision: 1.50 $   $Date: 2016/10/28 07:18:23 $
 #
 # Class "lpp" of point patterns on linear networks
 
 lpp <- function(X, L, ...) {
   stopifnot(inherits(L, "linnet"))
-  localnames <- c("seg", "tp")
-  spatialnames <- c("x", "y")
-  allcoordnames <- c(spatialnames, localnames)
-  if(is.matrix(X)) X <- as.data.frame(X)
-  if(checkfields(X, localnames)) {
-    # X includes at least local coordinates
-    X <- as.data.frame(X)
-    #' validate local coordinates
-    if(nrow(X) > 0) {
-      nedge <- nsegments(L)
-      if(with(X, any(seg < 1 || seg > nedge)))
-        stop("Segment index coordinate 'seg' exceeds bounds")
-      if(with(X, any(tp < 0 || tp > 1)))
-        stop("Local coordinate 'tp' outside [0,1]")
-    }
-    if(!checkfields(X, spatialnames)) {
-      #' data give local coordinates only
-      #' reconstruct x,y coordinates from local coordinates
-      Y <- local2lpp(L, X$seg, X$tp, df.only=TRUE)
-      X[,spatialnames] <- Y[,spatialnames,drop=FALSE]
-    }
-    #' local coordinates
-    lo <- X[ , localnames, drop=FALSE]
-    #' spatial coords and marks
-    marknames <- setdiff(names(X), allcoordnames)
-    df <- X[, c(spatialnames, marknames), drop=FALSE]
+  if(missing(X) || is.null(X)) {
+    ## empty pattern
+    df <- data.frame(x=numeric(0), y=numeric(0))
+    lo <- data.frame(seg=integer(0), tp=numeric(0))
   } else {
-    # local coordinates must be computed from spatial coordinates
-    if(!is.ppp(X))
-      X <- as.ppp(X, W=L$window, ...)
-    # project to segment
-    pro <- project2segment(X, as.psp(L))
-    # projected points (spatial coordinates and marks)
-    df  <- as.data.frame(pro$Xproj)
-    # local coordinates
-    lo  <- data.frame(seg=pro$mapXY, tp=pro$tp)
+    localnames <- c("seg", "tp")
+    spatialnames <- c("x", "y")
+    allcoordnames <- c(spatialnames, localnames)
+    if(is.matrix(X)) X <- as.data.frame(X)
+    if(checkfields(X, localnames)) {
+      #' X includes at least local coordinates
+      X <- as.data.frame(X)
+      #' validate local coordinates
+      if(nrow(X) > 0) {
+        nedge <- nsegments(L)
+        if(with(X, any(seg < 1 || seg > nedge)))
+          stop("Segment index coordinate 'seg' exceeds bounds")
+        if(with(X, any(tp < 0 || tp > 1)))
+          stop("Local coordinate 'tp' outside [0,1]")
+      }
+      if(!checkfields(X, spatialnames)) {
+        #' data give local coordinates only
+        #' reconstruct x,y coordinates from local coordinates
+        Y <- local2lpp(L, X$seg, X$tp, df.only=TRUE)
+        X[,spatialnames] <- Y[,spatialnames,drop=FALSE]
+      }
+      #' local coordinates
+      lo <- X[ , localnames, drop=FALSE]
+      #' spatial coords and marks
+      marknames <- setdiff(names(X), allcoordnames)
+      df <- X[, c(spatialnames, marknames), drop=FALSE]
+    } else {
+      #' local coordinates must be computed from spatial coordinates
+      if(!is.ppp(X))
+        X <- as.ppp(X, W=L$window, ...)
+      #' project to segment
+      pro <- project2segment(X, as.psp(L))
+      #' projected points (spatial coordinates and marks)
+      df  <- as.data.frame(pro$Xproj)
+      #' local coordinates
+      lo  <- data.frame(seg=pro$mapXY, tp=pro$tp)
+    }
   }
   # combine spatial, local, marks
   nmark <- ncol(df) - 2
@@ -552,3 +558,51 @@ identify.lpp <- function(x, ...) {
   row.names(out) <- NULL
   return(out)
 }
+
+cut.lpp <- function(x, z=marks(x), ...) {
+  if(missing(z) || is.null(z)) {
+    z <- marks(x, dfok=TRUE)
+    if(is.null(z))
+      stop("x has no marks to cut")
+  } else {
+    #' special objects
+    if(inherits(z, "linim")) {
+      z <- z[x, drop=FALSE]
+    } else if(inherits(z, "linfun")) {
+      z <- z(x)
+    } else if(inherits(z, "lintess")) {
+      z <- (as.linfun(z))(x)
+    }
+  }
+  #' standard data types
+  if(is.character(z)) {
+    if(length(z) == npoints(x)) {
+      # interpret as a factor
+      z <- factor(z)
+    } else if((length(z) == 1) && (z %in% colnames(df <- as.data.frame(x)))) {
+      # interpret as the name of a column of marks or a coordinate
+      zname <- z
+      z <- df[, zname]
+      if(zname == "seg") z <- factor(z)
+    } else stop("format of argument z not understood") 
+  }
+  if(is.factor(z) || is.vector(z)) {
+    stopifnot(length(z) == npoints(x))
+    g <- if(is.factor(z)) z else if(is.numeric(z)) cut(z, ...) else factor(z)
+    marks(x) <- g
+    return(x)
+  }
+  if(is.data.frame(z) || is.matrix(z)) {
+    stopifnot(nrow(z) == npoints(x))
+    # take first column 
+    z <- z[,1]
+    g <- if(is.numeric(z)) cut(z, ...) else factor(z)
+    marks(x) <- g
+    return(x)
+  }
+  stop("Format of z not understood")
+}
+
+points.lpp <- function(x, ...) {
+  points(coords(x, spatial=TRUE, local=FALSE), ...)
+}
